// import tip from '/common/util/tip.js';
import JSEncrypt  from './jsencrypt.min.js';
import Vue from 'vue'

/* 根据地址获取经纬度 */
export function addressToGeocode(key, address) {
	return new Promise((reserve, reject) => {
		uni.request({
			url: 'https://restapi.amap.com/v3/geocode/geo?parameters', 
			method:'GET',
			data: {
				key:key,
				address: address
			},
			success: (res) => {
				console.log('高德res',res.data.geocodes[0])
				if(res.data.geocodes[0]) {
					let jd = res.data.geocodes[0].location.split(',')[0]
					let wd = res.data.geocodes[0].location.split(',')[1]
					// Map.openMap(parseFloat(wd),parseFloat(jd), address, 'gcj02')
					reserve({jd, wd})
				}else {
					reject({code: 300})
				}
			},
			fail: (err) => {
				reject(err)
			}
		})
	})
}

/* 获取当前位置经纬度 */
export function getLocation1(targetRes={}) {
	const _this = this
	uni.getSetting({
		success(res) {
			if (res.authSetting['scope.userLocation']) {
				getLocation1(targetRes)
			} else {
				getAuthorize()
			}
		}
	})
}

// 用户授权
function getAuthorize() {
	const that = this
	uni.authorize({
		scope: 'scope.userLocation',
		success(res) {
			that.getLocation()
		},
		// 授权失败
		fail(err) {
			uni.showModal({
				title: '提示',
				content: '请授权位置',
				showCancel: false,
				confirmText: '确认授权',
				success() {
					uni.openSetting({
						success(res) {
							console.log(res)
						},
						fail(err) {
							console.log(err)
						}
					})
				}
			})
		}
	})
}

/* 根据经纬度计算距离 */
function distance(sourceRes={}, targetRes={}) {
	if(Object.keys(sourceRes).length != 0 && Object.keys(targetRes).length != 0) {
		const lat1 = sourceRes.latitude;
		const lng1 = sourceRes.longitude;
		const lat2 = targetRes.latitude;
		const lng2 = targetRes.longitude;
		const rad1 = lat1 * Math.PI / 180.0;
		const rad2 = lat2 * Math.PI / 180.0;
		const a = rad1 - rad2;
		const b = lng1 * Math.PI / 180.0 - lng2 * Math.PI / 180.0;
		
		let s = 2 * Math.asin(Math.sqrt(Math.pow(Math.sin(a / 2), 2) + Math.cos(rad1) * Math.cos(
			rad2) * Math.pow(
			Math.sin(b / 2), 2)));
		s = s * 6378.137;
		s = Math.round(s * 10000) / 10000;
		
		const distance = s;
		let distance_str = "";

		if (parseInt(distance) >= 1) {
			distance_str = distance.toFixed(1) + "km";
		} else {
			distance_str = distance * 1000 + "m";
		}
		console.log('距离：', distance_str);
		return distance_str
	}
	return 0
}

/* 获取当前位置经纬度 */
export function getLocation(targetRes={}) {
	return new Promise(async (reserve, reject) => {
		await uni.getLocation({
			type: 'gcj02',
			altitude: true,
			success(res) {
				console.log('当前经纬度信息：',res)
				if(Object.keys(targetRes).length != 0){
					const s = distance(res, targetRes)
					if(s) {
						reserve(s)
					}else {
						reject('计算错误')
					}
				}else{
					reserve(res)
				}
			},
			fail(err) {
				reject(err)
			}
		})
	})
	
}

/* 计算时间差 */
export function getDeltaT(newDate = new Date(), oldDate = new Date('2018-12-12 00:00:00')) {
	const difftime = newDate - oldDate; //计算时间差
	const years = parseInt(difftime/(86400 * 365)); //年
	const months = years*12 + (newDate.getMonth() - oldDate.getMonth()) > 0 ? newDate.getMonth() - oldDate.getMonth() : newDate.getMonth(); //月
	const days = parseInt(difftime/86400); // 天  24*60*60*1000 
	const hours = parseInt(difftime/3600)-24*days;    // 小时 60*60 总小时数-过去的小时数=现在的小时数 
	const minutes = parseInt(difftime%3600/60); // 分钟 -(day*24) 以60秒为一整份 取余 剩下秒数 秒数/60 就是分钟数
	const seconds = parseInt(difftime%60);  // 以60秒为一整份 取余 剩下秒数
	return {years, months, days, hours, minutes, seconds,}
}

/* 拨打电话 */
export function callSeler(phone){
	uni.makePhoneCall({
		// 手机号
		phoneNumber: phone, 
		// 成功回调
		success: (res) => {
			console.log('调用成功!')	
		},
		// 失败回调
		fail: (res) => {
			console.log('调用失败!')
		}
  });
}

